package testapigroup
import "k8s.io/apimachinery/pkg/apis/testapigroup"
+k8s:deepcopy-gen=package +groupName=testapigroup.apimachinery.k8s.io
package testapigroup contains an testapigroup API used to demonstrate how to create api groups. Moreover, this is used within tests.
Index ¶
- Constants
- Variables
- func Kind(kind string) schema.GroupKind
- func Resource(resource string) schema.GroupResource
- type Carp
- func (in *Carp) DeepCopy() *Carp
- func (in *Carp) DeepCopyInto(out *Carp)
- func (in *Carp) DeepCopyObject() runtime.Object
- type CarpCondition
- func (in *CarpCondition) DeepCopy() *CarpCondition
- func (in *CarpCondition) DeepCopyInto(out *CarpCondition)
- type CarpConditionType
- type CarpInfo
- type CarpList
- func (in *CarpList) DeepCopy() *CarpList
- func (in *CarpList) DeepCopyInto(out *CarpList)
- func (in *CarpList) DeepCopyObject() runtime.Object
- type CarpPhase
- type CarpSpec
- type CarpStatus
- type ConditionStatus
- type RestartPolicy
Constants ¶
const GroupName = "testapigroup.apimachinery.k8s.io"
GroupName is the group name use in this package
Variables ¶
var ( SchemeBuilder = runtime.NewSchemeBuilder(addKnownTypes) AddToScheme = SchemeBuilder.AddToScheme )
var SchemeGroupVersion = schema.GroupVersion{Group: GroupName, Version: runtime.APIVersionInternal}
SchemeGroupVersion is group version used to register these objects
Functions ¶
func Kind ¶
Kind takes an unqualified kind and returns a Group qualified GroupKind
func Resource ¶
func Resource(resource string) schema.GroupResource
Resource takes an unqualified resource and returns a Group qualified GroupResource
Types ¶
type Carp ¶
type Carp struct {
metav1.TypeMeta
// +optional
metav1.ObjectMeta
// Spec defines the behavior of a carp.
// +optional
Spec CarpSpec
// Status represents the current information about a carp. This data may not be up
// to date.
// +optional
Status CarpStatus
}
Carp is a collection of containers, used as either input (create, update) or as output (list, get).
func (*Carp) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Carp.
func (*Carp) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*Carp) DeepCopyObject ¶
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type CarpCondition ¶
type CarpCondition struct {
Type CarpConditionType
Status ConditionStatus
// +optional
LastProbeTime metav1.Time
// +optional
LastTransitionTime metav1.Time
// +optional
Reason string
// +optional
Message string
}
func (*CarpCondition) DeepCopy ¶
func (in *CarpCondition) DeepCopy() *CarpCondition
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CarpCondition.
func (*CarpCondition) DeepCopyInto ¶
func (in *CarpCondition) DeepCopyInto(out *CarpCondition)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type CarpConditionType ¶
type CarpConditionType string
type CarpInfo ¶
type CarpInfo struct {
// A is the first map key.
// +required
A int64
// B is the second map key.
// +required
B string
// C is the third, optional map key
// +optional
C *string
// Some data for each pair of A and B.
Data string
}
func (*CarpInfo) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CarpInfo.
func (*CarpInfo) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type CarpList ¶
CarpList is a list of Carps.
func (*CarpList) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CarpList.
func (*CarpList) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*CarpList) DeepCopyObject ¶
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type CarpPhase ¶
type CarpPhase string
type CarpSpec ¶
type CarpSpec struct {
// +optional
RestartPolicy RestartPolicy
// Optional duration in seconds the carp needs to terminate gracefully. May be decreased in delete request.
// Value must be non-negative integer. The value zero indicates delete immediately.
// If this value is nil, the default grace period will be used instead.
// The grace period is the duration in seconds after the processes running in the carp are sent
// a termination signal and the time when the processes are forcibly halted with a kill signal.
// Set this value longer than the expected cleanup time for your process.
// +optional
TerminationGracePeriodSeconds *int64
// Optional duration in seconds relative to the StartTime that the carp may be active on a node
// before the system actively tries to terminate the carp; value must be positive integer
// +optional
ActiveDeadlineSeconds *int64
// NodeSelector is a selector which must be true for the carp to fit on a node
// +optional
NodeSelector map[string]string
// ServiceAccountName is the name of the ServiceAccount to use to run this carp
// The carp will be allowed to use secrets referenced by the ServiceAccount
ServiceAccountName string
// NodeName is a request to schedule this carp onto a specific node. If it is non-empty,
// the scheduler simply schedules this carp onto that node, assuming that it fits resource
// requirements.
// +optional
NodeName string
// Specifies the hostname of the Carp.
// If not specified, the carp's hostname will be set to a system-defined value.
// +optional
Hostname string
// If specified, the fully qualified Carp hostname will be "<hostname>.<subdomain>.<carp namespace>.svc.<cluster domain>".
// If not specified, the carp will not have a domainname at all.
// +optional
Subdomain string
// If specified, the carp will be dispatched by specified scheduler.
// If not specified, the carp will be dispatched by default scheduler.
// +optional
SchedulerName string
}
CarpSpec is a description of a carp
func (*CarpSpec) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CarpSpec.
func (*CarpSpec) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type CarpStatus ¶
type CarpStatus struct {
// +optional
Phase CarpPhase
// +optional
Conditions []CarpCondition
// A human readable message indicating details about why the carp is in this state.
// +optional
Message string
// A brief CamelCase message indicating details about why the carp is in this state. e.g. 'DiskPressure'
// +optional
Reason string
// +optional
HostIP string
// +optional
CarpIP string
// Date and time at which the object was acknowledged by the Kubelet.
// This is before the Kubelet pulled the container image(s) for the carp.
// +optional
StartTime *metav1.Time
// Carp infos are provided by different clients, hence the map type.
//
// +listType=map
// +listKey=a
// +listKey=b
// +listKey=c
Infos []CarpInfo
}
CarpStatus represents information about the status of a carp. Status may trail the actual state of a system.
func (*CarpStatus) DeepCopy ¶
func (in *CarpStatus) DeepCopy() *CarpStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CarpStatus.
func (*CarpStatus) DeepCopyInto ¶
func (in *CarpStatus) DeepCopyInto(out *CarpStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ConditionStatus ¶
type ConditionStatus string
type RestartPolicy ¶
type RestartPolicy string
Source Files ¶
doc.go register.go types.go zz_generated.deepcopy.go
Directories ¶
| Path | Synopsis |
|---|---|
| pkg/apis/testapigroup/fuzzer | |
| pkg/apis/testapigroup/install | Package install installs the certificates API group, making it available as an option to all of the API encoding/decoding machinery. |
| pkg/apis/testapigroup/v1 |
- Version
- v0.34.1
- Published
- Aug 16, 2025
- Platform
- linux/amd64
- Imports
- 3 packages
- Last checked
- 28 minutes ago –
Tools for package owners.