package v1

import "k8s.io/apimachinery/pkg/apis/testapigroup/v1"

Index

Constants

const GroupName = "testapigroup.apimachinery.k8s.io"

GroupName is the group name use in this package

Variables

var (
	ErrInvalidLengthGenerated        = fmt.Errorf("proto: negative length found during unmarshaling")
	ErrIntOverflowGenerated          = fmt.Errorf("proto: integer overflow")
	ErrUnexpectedEndOfGroupGenerated = fmt.Errorf("proto: unexpected end of group")
)
var (
	// TODO: move SchemeBuilder with zz_generated.deepcopy.go to k8s.io/api.
	// localSchemeBuilder and AddToScheme will stay in k8s.io/kubernetes.
	SchemeBuilder runtime.SchemeBuilder

	AddToScheme = localSchemeBuilder.AddToScheme
)
var SchemeGroupVersion = schema.GroupVersion{Group: GroupName, Version: "v1"}

SchemeGroupVersion is group version used to register these objects

Functions

func Convert_testapigroup_CarpCondition_To_v1_CarpCondition

func Convert_testapigroup_CarpCondition_To_v1_CarpCondition(in *testapigroup.CarpCondition, out *CarpCondition, s conversion.Scope) error

Convert_testapigroup_CarpCondition_To_v1_CarpCondition is an autogenerated conversion function.

func Convert_testapigroup_CarpInfo_To_v1_CarpInfo

func Convert_testapigroup_CarpInfo_To_v1_CarpInfo(in *testapigroup.CarpInfo, out *CarpInfo, s conversion.Scope) error

Convert_testapigroup_CarpInfo_To_v1_CarpInfo is an autogenerated conversion function.

func Convert_testapigroup_CarpList_To_v1_CarpList

func Convert_testapigroup_CarpList_To_v1_CarpList(in *testapigroup.CarpList, out *CarpList, s conversion.Scope) error

Convert_testapigroup_CarpList_To_v1_CarpList is an autogenerated conversion function.

func Convert_testapigroup_CarpSpec_To_v1_CarpSpec

func Convert_testapigroup_CarpSpec_To_v1_CarpSpec(in *testapigroup.CarpSpec, out *CarpSpec, s conversion.Scope) error

Convert_testapigroup_CarpSpec_To_v1_CarpSpec is an autogenerated conversion function.

func Convert_testapigroup_CarpStatus_To_v1_CarpStatus

func Convert_testapigroup_CarpStatus_To_v1_CarpStatus(in *testapigroup.CarpStatus, out *CarpStatus, s conversion.Scope) error

Convert_testapigroup_CarpStatus_To_v1_CarpStatus is an autogenerated conversion function.

func Convert_testapigroup_Carp_To_v1_Carp

func Convert_testapigroup_Carp_To_v1_Carp(in *testapigroup.Carp, out *Carp, s conversion.Scope) error

Convert_testapigroup_Carp_To_v1_Carp is an autogenerated conversion function.

func Convert_v1_CarpCondition_To_testapigroup_CarpCondition

func Convert_v1_CarpCondition_To_testapigroup_CarpCondition(in *CarpCondition, out *testapigroup.CarpCondition, s conversion.Scope) error

Convert_v1_CarpCondition_To_testapigroup_CarpCondition is an autogenerated conversion function.

func Convert_v1_CarpInfo_To_testapigroup_CarpInfo

func Convert_v1_CarpInfo_To_testapigroup_CarpInfo(in *CarpInfo, out *testapigroup.CarpInfo, s conversion.Scope) error

Convert_v1_CarpInfo_To_testapigroup_CarpInfo is an autogenerated conversion function.

func Convert_v1_CarpList_To_testapigroup_CarpList

func Convert_v1_CarpList_To_testapigroup_CarpList(in *CarpList, out *testapigroup.CarpList, s conversion.Scope) error

Convert_v1_CarpList_To_testapigroup_CarpList is an autogenerated conversion function.

func Convert_v1_CarpSpec_To_testapigroup_CarpSpec

func Convert_v1_CarpSpec_To_testapigroup_CarpSpec(in *CarpSpec, out *testapigroup.CarpSpec, s conversion.Scope) error

Convert_v1_CarpSpec_To_testapigroup_CarpSpec is an autogenerated conversion function.

func Convert_v1_CarpStatus_To_testapigroup_CarpStatus

func Convert_v1_CarpStatus_To_testapigroup_CarpStatus(in *CarpStatus, out *testapigroup.CarpStatus, s conversion.Scope) error

Convert_v1_CarpStatus_To_testapigroup_CarpStatus is an autogenerated conversion function.

func Convert_v1_Carp_To_testapigroup_Carp

func Convert_v1_Carp_To_testapigroup_Carp(in *Carp, out *testapigroup.Carp, s conversion.Scope) error

Convert_v1_Carp_To_testapigroup_Carp is an autogenerated conversion function.

func Kind

func Kind(kind string) schema.GroupKind

Kind takes an unqualified kind and returns a Group qualified GroupKind

func RegisterConversions

func RegisterConversions(s *runtime.Scheme) error

RegisterConversions adds conversion functions to the given scheme. Public to allow building arbitrary schemes.

func RegisterDefaults

func RegisterDefaults(scheme *runtime.Scheme) error

RegisterDefaults adds defaulters functions to the given scheme. Public to allow building arbitrary schemes. All generated defaulters are covering - they call all nested defaulters.

func Resource

func Resource(resource string) schema.GroupResource

Resource takes an unqualified resource and returns a Group qualified GroupResource

Types

type Carp

type Carp struct {
	metav1.TypeMeta `json:",inline"`
	// Standard object's metadata.
	// More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
	// +optional
	metav1.ObjectMeta `json:"metadata,omitempty" protobuf:"bytes,1,opt,name=metadata"`

	// Specification of the desired behavior of the carp.
	// More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status
	// +optional
	Spec CarpSpec `json:"spec,omitempty" protobuf:"bytes,2,opt,name=spec"`

	// Most recently observed status of the carp.
	// This data may not be up to date.
	// Populated by the system.
	// Read-only.
	// More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status
	// +optional
	Status CarpStatus `json:"status,omitempty" protobuf:"bytes,3,opt,name=status"`
}

Carp is a collection of containers, used as either input (create, update) or as output (list, get).

func (*Carp) APILifecycleIntroduced

func (in *Carp) APILifecycleIntroduced() (major, minor int)

APILifecycleIntroduced is an autogenerated function, returning the release in which the API struct was introduced as int versions of major and minor for comparison. It is controlled by "k8s:prerelease-lifecycle-gen:introduced" tags in types.go.

func (*Carp) DeepCopy

func (in *Carp) DeepCopy() *Carp

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Carp.

func (*Carp) DeepCopyInto

func (in *Carp) DeepCopyInto(out *Carp)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

func (*Carp) DeepCopyObject

func (in *Carp) DeepCopyObject() runtime.Object

DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.

func (*Carp) Descriptor

func (*Carp) Descriptor() ([]byte, []int)

func (*Carp) Marshal

func (m *Carp) Marshal() (dAtA []byte, err error)

func (*Carp) MarshalTo

func (m *Carp) MarshalTo(dAtA []byte) (int, error)

func (*Carp) MarshalToSizedBuffer

func (m *Carp) MarshalToSizedBuffer(dAtA []byte) (int, error)

func (*Carp) ProtoMessage

func (*Carp) ProtoMessage()

func (*Carp) Reset

func (m *Carp) Reset()

func (*Carp) Size

func (m *Carp) Size() (n int)

func (*Carp) String

func (this *Carp) String() string

func (*Carp) Unmarshal

func (m *Carp) Unmarshal(dAtA []byte) error

func (*Carp) XXX_DiscardUnknown

func (m *Carp) XXX_DiscardUnknown()

func (*Carp) XXX_Marshal

func (m *Carp) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*Carp) XXX_Merge

func (m *Carp) XXX_Merge(src proto.Message)

func (*Carp) XXX_Size

func (m *Carp) XXX_Size() int

func (*Carp) XXX_Unmarshal

func (m *Carp) XXX_Unmarshal(b []byte) error

type CarpCondition

type CarpCondition struct {
	// Type is the type of the condition.
	// Currently only Ready.
	// More info: http://kubernetes.io/docs/user-guide/carp-states#carp-conditions
	Type CarpConditionType `json:"type" protobuf:"bytes,1,opt,name=type,casttype=CarpConditionType"`
	// Status is the status of the condition.
	// Can be True, False, Unknown.
	// More info: http://kubernetes.io/docs/user-guide/carp-states#carp-conditions
	Status ConditionStatus `json:"status" protobuf:"bytes,2,opt,name=status,casttype=ConditionStatus"`
	// Last time we probed the condition.
	// +optional
	LastProbeTime metav1.Time `json:"lastProbeTime,omitempty" protobuf:"bytes,3,opt,name=lastProbeTime"`
	// Last time the condition transitioned from one status to another.
	// +optional
	LastTransitionTime metav1.Time `json:"lastTransitionTime,omitempty" protobuf:"bytes,4,opt,name=lastTransitionTime"`
	// Unique, one-word, CamelCase reason for the condition's last transition.
	// +optional
	Reason string `json:"reason,omitempty" protobuf:"bytes,5,opt,name=reason"`
	// Human-readable message indicating details about last transition.
	// +optional
	Message string `json:"message,omitempty" protobuf:"bytes,6,opt,name=message"`
}

func (*CarpCondition) DeepCopy

func (in *CarpCondition) DeepCopy() *CarpCondition

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CarpCondition.

func (*CarpCondition) DeepCopyInto

func (in *CarpCondition) DeepCopyInto(out *CarpCondition)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

func (*CarpCondition) Descriptor

func (*CarpCondition) Descriptor() ([]byte, []int)

func (*CarpCondition) Marshal

func (m *CarpCondition) Marshal() (dAtA []byte, err error)

func (*CarpCondition) MarshalTo

func (m *CarpCondition) MarshalTo(dAtA []byte) (int, error)

func (*CarpCondition) MarshalToSizedBuffer

func (m *CarpCondition) MarshalToSizedBuffer(dAtA []byte) (int, error)

func (*CarpCondition) ProtoMessage

func (*CarpCondition) ProtoMessage()

func (*CarpCondition) Reset

func (m *CarpCondition) Reset()

func (*CarpCondition) Size

func (m *CarpCondition) Size() (n int)

func (*CarpCondition) String

func (this *CarpCondition) String() string

func (*CarpCondition) Unmarshal

func (m *CarpCondition) Unmarshal(dAtA []byte) error

func (*CarpCondition) XXX_DiscardUnknown

func (m *CarpCondition) XXX_DiscardUnknown()

func (*CarpCondition) XXX_Marshal

func (m *CarpCondition) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*CarpCondition) XXX_Merge

func (m *CarpCondition) XXX_Merge(src proto.Message)

func (*CarpCondition) XXX_Size

func (m *CarpCondition) XXX_Size() int

func (*CarpCondition) XXX_Unmarshal

func (m *CarpCondition) XXX_Unmarshal(b []byte) error

type CarpConditionType

type CarpConditionType string

type CarpInfo

type CarpInfo struct {
	// A is the first map key.
	// +required
	A int64 `json:"a" protobuf:"bytes,1,name=a"`
	// B is the second map key.
	// +required
	B string `json:"b" protobuf:"bytes,2,name=b"`
	// C is the third, optional map key
	// +optional
	C *string `json:"c,omitempty" protobuf:"bytes,4,opt,name=c"`

	// Some data for each pair of A and B.
	Data string `json:"data" protobuf:"bytes,3,name=data"`
}

func (*CarpInfo) DeepCopy

func (in *CarpInfo) DeepCopy() *CarpInfo

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CarpInfo.

func (*CarpInfo) DeepCopyInto

func (in *CarpInfo) DeepCopyInto(out *CarpInfo)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

func (*CarpInfo) Descriptor

func (*CarpInfo) Descriptor() ([]byte, []int)

func (*CarpInfo) Marshal

func (m *CarpInfo) Marshal() (dAtA []byte, err error)

func (*CarpInfo) MarshalTo

func (m *CarpInfo) MarshalTo(dAtA []byte) (int, error)

func (*CarpInfo) MarshalToSizedBuffer

func (m *CarpInfo) MarshalToSizedBuffer(dAtA []byte) (int, error)

func (*CarpInfo) ProtoMessage

func (*CarpInfo) ProtoMessage()

func (*CarpInfo) Reset

func (m *CarpInfo) Reset()

func (*CarpInfo) Size

func (m *CarpInfo) Size() (n int)

func (*CarpInfo) String

func (this *CarpInfo) String() string

func (*CarpInfo) Unmarshal

func (m *CarpInfo) Unmarshal(dAtA []byte) error

func (*CarpInfo) XXX_DiscardUnknown

func (m *CarpInfo) XXX_DiscardUnknown()

func (*CarpInfo) XXX_Marshal

func (m *CarpInfo) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*CarpInfo) XXX_Merge

func (m *CarpInfo) XXX_Merge(src proto.Message)

func (*CarpInfo) XXX_Size

func (m *CarpInfo) XXX_Size() int

func (*CarpInfo) XXX_Unmarshal

func (m *CarpInfo) XXX_Unmarshal(b []byte) error

type CarpList

type CarpList struct {
	metav1.TypeMeta `json:",inline"`
	// Standard list metadata.
	// More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
	// +optional
	metav1.ListMeta `json:"metadata,omitempty" protobuf:"bytes,1,opt,name=metadata"`

	// List of carps.
	// More info: http://kubernetes.io/docs/user-guide/carps
	Items []Carp `json:"items" protobuf:"bytes,2,rep,name=items"`
}

CarpList is a list of Carps.

func (*CarpList) APILifecycleIntroduced

func (in *CarpList) APILifecycleIntroduced() (major, minor int)

APILifecycleIntroduced is an autogenerated function, returning the release in which the API struct was introduced as int versions of major and minor for comparison. It is controlled by "k8s:prerelease-lifecycle-gen:introduced" tags in types.go.

func (*CarpList) DeepCopy

func (in *CarpList) DeepCopy() *CarpList

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CarpList.

func (*CarpList) DeepCopyInto

func (in *CarpList) DeepCopyInto(out *CarpList)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

func (*CarpList) DeepCopyObject

func (in *CarpList) DeepCopyObject() runtime.Object

DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.

func (*CarpList) Descriptor

func (*CarpList) Descriptor() ([]byte, []int)

func (*CarpList) Marshal

func (m *CarpList) Marshal() (dAtA []byte, err error)

func (*CarpList) MarshalTo

func (m *CarpList) MarshalTo(dAtA []byte) (int, error)

func (*CarpList) MarshalToSizedBuffer

func (m *CarpList) MarshalToSizedBuffer(dAtA []byte) (int, error)

func (*CarpList) ProtoMessage

func (*CarpList) ProtoMessage()

func (*CarpList) Reset

func (m *CarpList) Reset()

func (*CarpList) Size

func (m *CarpList) Size() (n int)

func (*CarpList) String

func (this *CarpList) String() string

func (*CarpList) Unmarshal

func (m *CarpList) Unmarshal(dAtA []byte) error

func (*CarpList) XXX_DiscardUnknown

func (m *CarpList) XXX_DiscardUnknown()

func (*CarpList) XXX_Marshal

func (m *CarpList) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*CarpList) XXX_Merge

func (m *CarpList) XXX_Merge(src proto.Message)

func (*CarpList) XXX_Size

func (m *CarpList) XXX_Size() int

func (*CarpList) XXX_Unmarshal

func (m *CarpList) XXX_Unmarshal(b []byte) error

type CarpPhase

type CarpPhase string

type CarpSpec

type CarpSpec struct {
	// Restart policy for all containers within the carp.
	// One of Always, OnFailure, Never.
	// Default to Always.
	// More info: http://kubernetes.io/docs/user-guide/carp-states#restartpolicy
	// +optional
	RestartPolicy RestartPolicy `json:"restartPolicy,omitempty" protobuf:"bytes,3,opt,name=restartPolicy,casttype=RestartPolicy"`
	// Optional duration in seconds the carp needs to terminate gracefully. May be decreased in delete request.
	// Value must be non-negative integer. The value zero indicates delete immediately.
	// If this value is nil, the default grace period will be used instead.
	// The grace period is the duration in seconds after the processes running in the carp are sent
	// a termination signal and the time when the processes are forcibly halted with a kill signal.
	// Set this value longer than the expected cleanup time for your process.
	// Defaults to 30 seconds.
	// +optional
	TerminationGracePeriodSeconds *int64 `json:"terminationGracePeriodSeconds,omitempty" protobuf:"varint,4,opt,name=terminationGracePeriodSeconds"`
	// Optional duration in seconds the carp may be active on the node relative to
	// StartTime before the system will actively try to mark it failed and kill associated containers.
	// Value must be a positive integer.
	// +optional
	ActiveDeadlineSeconds *int64 `json:"activeDeadlineSeconds,omitempty" protobuf:"varint,5,opt,name=activeDeadlineSeconds"`
	// NodeSelector is a selector which must be true for the carp to fit on a node.
	// Selector which must match a node's labels for the carp to be scheduled on that node.
	// More info: http://kubernetes.io/docs/user-guide/node-selection/README
	// +optional
	NodeSelector map[string]string `json:"nodeSelector,omitempty" protobuf:"bytes,7,rep,name=nodeSelector"`

	// ServiceAccountName is the name of the ServiceAccount to use to run this carp.
	// More info: https://kubernetes.io/docs/concepts/security/service-accounts/
	// +optional
	ServiceAccountName string `json:"serviceAccountName,omitempty" protobuf:"bytes,8,opt,name=serviceAccountName"`
	// DeprecatedServiceAccount is a deprecated alias for ServiceAccountName.
	// Deprecated: Use serviceAccountName instead.
	// +k8s:conversion-gen=false
	// +optional
	DeprecatedServiceAccount string `json:"deprecatedServiceAccount,omitempty" protobuf:"bytes,9,opt,name=deprecatedServiceAccount"`

	// NodeName is a request to schedule this carp onto a specific node. If it is non-empty,
	// the scheduler simply schedules this carp onto that node, assuming that it fits resource
	// requirements.
	// +optional
	NodeName string `json:"nodeName,omitempty" protobuf:"bytes,10,opt,name=nodeName"`
	// Host networking requested for this carp. Use the host's network namespace.
	// Default to false.
	// +k8s:conversion-gen=false
	// +optional
	HostNetwork bool `json:"hostNetwork,omitempty" protobuf:"varint,11,opt,name=hostNetwork"`
	// Use the host's pid namespace.
	// Optional: Default to false.
	// +k8s:conversion-gen=false
	// +optional
	HostPID bool `json:"hostPID,omitempty" protobuf:"varint,12,opt,name=hostPID"`
	// Use the host's ipc namespace.
	// Optional: Default to false.
	// +k8s:conversion-gen=false
	// +optional
	HostIPC bool `json:"hostIPC,omitempty" protobuf:"varint,13,opt,name=hostIPC"`
	// Specifies the hostname of the Carp
	// If not specified, the carp's hostname will be set to a system-defined value.
	// +optional
	Hostname string `json:"hostname,omitempty" protobuf:"bytes,16,opt,name=hostname"`
	// If specified, the fully qualified Carp hostname will be "<hostname>.<subdomain>.<carp namespace>.svc.<cluster domain>".
	// If not specified, the carp will not have a domainname at all.
	// +optional
	Subdomain string `json:"subdomain,omitempty" protobuf:"bytes,17,opt,name=subdomain"`
	// If specified, the carp will be dispatched by specified scheduler.
	// If not specified, the carp will be dispatched by default scheduler.
	// +optional
	SchedulerName string `json:"schedulerName,omitempty" protobuf:"bytes,19,opt,name=schedulerName"`
}

CarpSpec is a description of a carp

func (*CarpSpec) DeepCopy

func (in *CarpSpec) DeepCopy() *CarpSpec

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CarpSpec.

func (*CarpSpec) DeepCopyInto

func (in *CarpSpec) DeepCopyInto(out *CarpSpec)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

func (*CarpSpec) Descriptor

func (*CarpSpec) Descriptor() ([]byte, []int)

func (*CarpSpec) Marshal

func (m *CarpSpec) Marshal() (dAtA []byte, err error)

func (*CarpSpec) MarshalTo

func (m *CarpSpec) MarshalTo(dAtA []byte) (int, error)

func (*CarpSpec) MarshalToSizedBuffer

func (m *CarpSpec) MarshalToSizedBuffer(dAtA []byte) (int, error)

func (*CarpSpec) ProtoMessage

func (*CarpSpec) ProtoMessage()

func (*CarpSpec) Reset

func (m *CarpSpec) Reset()

func (*CarpSpec) Size

func (m *CarpSpec) Size() (n int)

func (*CarpSpec) String

func (this *CarpSpec) String() string

func (*CarpSpec) Unmarshal

func (m *CarpSpec) Unmarshal(dAtA []byte) error

func (*CarpSpec) XXX_DiscardUnknown

func (m *CarpSpec) XXX_DiscardUnknown()

func (*CarpSpec) XXX_Marshal

func (m *CarpSpec) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*CarpSpec) XXX_Merge

func (m *CarpSpec) XXX_Merge(src proto.Message)

func (*CarpSpec) XXX_Size

func (m *CarpSpec) XXX_Size() int

func (*CarpSpec) XXX_Unmarshal

func (m *CarpSpec) XXX_Unmarshal(b []byte) error

type CarpStatus

type CarpStatus struct {
	// Current condition of the carp.
	// More info: http://kubernetes.io/docs/user-guide/carp-states#carp-phase
	// +optional
	Phase CarpPhase `json:"phase,omitempty" protobuf:"bytes,1,opt,name=phase,casttype=CarpPhase"`
	// Current service state of carp.
	// More info: http://kubernetes.io/docs/user-guide/carp-states#carp-conditions
	// +patchStrategy=merge
	// +patchMergeKey=type
	// +listType=map
	// +listMapKey=type
	// +optional
	Conditions []CarpCondition `json:"conditions,omitempty" patchStrategy:"merge" patchMergeKey:"type" protobuf:"bytes,2,opt,name=conditions"`
	// A human readable message indicating details about why the carp is in this condition.
	// +optional
	Message string `json:"message,omitempty" protobuf:"bytes,3,opt,name=message"`
	// A brief CamelCase message indicating details about why the carp is in this state.
	// e.g. 'DiskPressure'
	// +optional
	Reason string `json:"reason,omitempty" protobuf:"bytes,4,opt,name=reason"`

	// IP address of the host to which the carp is assigned. Empty if not yet scheduled.
	// +optional
	HostIP string `json:"hostIP,omitempty" protobuf:"bytes,5,opt,name=hostIP"`
	// IP address allocated to the carp. Routable at least within the cluster.
	// Empty if not yet allocated.
	// +optional
	CarpIP string `json:"carpIP,omitempty" protobuf:"bytes,6,opt,name=carpIP"`

	// RFC 3339 date and time at which the object was acknowledged by the Kubelet.
	// This is before the Kubelet pulled the container image(s) for the carp.
	// +optional
	StartTime *metav1.Time `json:"startTime,omitempty" protobuf:"bytes,7,opt,name=startTime"`

	// Carp infos are provided by different clients, hence the map type.
	//
	// +listType=map
	// +listMapKey=a
	// +listMapKey=b
	// +listMapKey=c
	Infos []CarpInfo `json:"infos,omitempty" protobuf:"bytes,8,rep,name=infos"`
}

CarpStatus represents information about the status of a carp. Status may trail the actual state of a system.

func (*CarpStatus) DeepCopy

func (in *CarpStatus) DeepCopy() *CarpStatus

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CarpStatus.

func (*CarpStatus) DeepCopyInto

func (in *CarpStatus) DeepCopyInto(out *CarpStatus)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

func (*CarpStatus) Descriptor

func (*CarpStatus) Descriptor() ([]byte, []int)

func (*CarpStatus) Marshal

func (m *CarpStatus) Marshal() (dAtA []byte, err error)

func (*CarpStatus) MarshalTo

func (m *CarpStatus) MarshalTo(dAtA []byte) (int, error)

func (*CarpStatus) MarshalToSizedBuffer

func (m *CarpStatus) MarshalToSizedBuffer(dAtA []byte) (int, error)

func (*CarpStatus) ProtoMessage

func (*CarpStatus) ProtoMessage()

func (*CarpStatus) Reset

func (m *CarpStatus) Reset()

func (*CarpStatus) Size

func (m *CarpStatus) Size() (n int)

func (*CarpStatus) String

func (this *CarpStatus) String() string

func (*CarpStatus) Unmarshal

func (m *CarpStatus) Unmarshal(dAtA []byte) error

func (*CarpStatus) XXX_DiscardUnknown

func (m *CarpStatus) XXX_DiscardUnknown()

func (*CarpStatus) XXX_Marshal

func (m *CarpStatus) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*CarpStatus) XXX_Merge

func (m *CarpStatus) XXX_Merge(src proto.Message)

func (*CarpStatus) XXX_Size

func (m *CarpStatus) XXX_Size() int

func (*CarpStatus) XXX_Unmarshal

func (m *CarpStatus) XXX_Unmarshal(b []byte) error

type ConditionStatus

type ConditionStatus string

type RestartPolicy

type RestartPolicy string

Source Files

conversion.go defaults.go doc.go generated.pb.go register.go types.go zz_generated.conversion.go zz_generated.deepcopy.go zz_generated.defaults.go zz_generated.prerelease-lifecycle.go

Version
v0.34.5
Published
Aug 16, 2025
Platform
linux/amd64
Imports
14 packages
Last checked
2 hours ago

Tools for package owners.