package cbor
import "k8s.io/apimachinery/pkg/runtime/serializer/cbor"
Index ¶
Types ¶
type Option ¶
type Option func(*options)
func Strict ¶
type Serializer ¶
type Serializer interface {
runtime.Serializer
recognizer.RecognizingDecoder
}
func NewSerializer ¶
func NewSerializer(creater runtime.ObjectCreater, typer runtime.ObjectTyper, options ...Option) Serializer
Source Files ¶
cbor.go
Directories ¶
| Path | Synopsis |
|---|---|
| pkg/runtime/serializer/cbor/direct | Package direct provides functions for marshaling and unmarshaling between arbitrary Go values and CBOR data, with behavior that is compatible with that of the CBOR serializer. |
| pkg/runtime/serializer/cbor/internal |
- Version
- v0.30.14
- Published
- Jul 29, 2024
- Platform
- linux/amd64
- Imports
- 12 packages
- Last checked
- 12 minutes ago –
Tools for package owners.